@@ -7,14 +7,16 @@ import joblib
 import pandas as pd
 import truvari
 
+
 def make_tech(data):
     """
     Add tech and tech_str columns to the data frame
     """
-    flag = {1:"PB", 2:"Ill", 4:"TenX", 8:"CG"}
+    flag = {1: "PB", 2: "Ill", 4: "TenX", 8: "CG"}
     data['tech'] = 0
     for val, col in enumerate(["PBcalls", "Illcalls", "TenXcalls", "CGcalls"]):
         data['tech'] += (data[col] != 0).astype(int) * (val + 1) ** 2
+
     def make_tech_str(x):
         ret = []
         for key, value in flag.items():
@@ -25,6 +27,7 @@ def make_tech(data):
         return None
     data["tech_str"] = data['tech'].apply(make_tech_str)
 
+
 def make_giabreport(args, stats_box):
     """
     Create summaries of the TPs/FNs
@@ -32,7 +35,8 @@ def make_giabreport(args, stats_box):
     out_df = os.path.join(args.output, "giab.jl")
     truvari.vcf2df.vcf2df_main(["-i", "-f", "-b", args.output, out_df])
     data = joblib.load(out_df)
-    sz_type = pd.CategoricalDtype(categories=["50to99", "100to299", "300to999", "gt1000"], ordered=True)
+    sz_type = pd.CategoricalDtype(
+        categories=["50to99", "100to299", "300to999", "gt1000"], ordered=True)
     data["sizecat"] = data["sizecat"].astype(sz_type)
     make_tech(data)
     with open(os.path.join(args.output, "giab_report.txt"), 'w') as sum_out:
@@ -46,20 +50,23 @@ def make_giabreport(args, stats_box):
 
         base_calls = data["state"].isin(["tpbase", "fn"])
         sum_out.write("# State by SizeCat and SVTYPE\n")
-        view = data[base_calls].groupby(["sizecat", "SVTYPE", "state"]).size().unstack(fill_value=0)
+        view = data[base_calls].groupby(
+            ["sizecat", "SVTYPE", "state"]).size().unstack(fill_value=0)
         view["pct"] = view["tpbase"] / view.sum(axis=1)
         sum_out.write(view.to_csv(sep="\t") + '\n')
         sum_out.write("\n")
 
         sum_out.write("# State by REPTYPE\n")
-        view = data[base_calls].groupby(["REPTYPE", "state"]).size().unstack(fill_value=0)
+        view = data[base_calls].groupby(
+            ["REPTYPE", "state"]).size().unstack(fill_value=0)
         view["pct"] = view["tpbase"] / (view["fn"] + view["tpbase"])
         view.sort_index(inplace=True)
         sum_out.write(view.to_csv(sep="\t") + '\n')
         sum_out.write("\n")
 
         sum_out.write("# State by Tech\n")
-        view = data[base_calls].groupby(["tech_str", "state"]).size().unstack(fill_value=0).sort_index()
+        view = data[base_calls].groupby(
+            ["tech_str", "state"]).size().unstack(fill_value=0).sort_index()
         view["pct"] = view["tpbase"] / view.sum(axis=1)
         sum_out.write(view.to_csv(sep="\t") + '\n')
         sum_out.write("\n")
@@ -69,8 +76,10 @@ def make_giabreport(args, stats_box):
         view = data.groupby(["state", "HG002_GT"]).size().unstack(fill_value=0)
         view.loc["total"] = view.sum(axis=0)
         view["TOT"] = view.sum(axis=1)
-        view.loc["recall"] = view.loc["tpbase"] / (view.loc["tpbase"] + view.loc["fn"])
-        view.loc["precision"] = view.loc["tp"] / (view.loc["tp"] + view.loc["fp"])
+        view.loc["recall"] = view.loc["tpbase"] / \
+            (view.loc["tpbase"] + view.loc["fn"])
+        view.loc["precision"] = view.loc["tp"] / \
+            (view.loc["tp"] + view.loc["fp"])
         view = view.round(decimals=2)
         sum_out.write(view.to_csv(sep="\t") + '\n')
         sum_out.write("\n")
@@ -78,5 +87,5 @@ def make_giabreport(args, stats_box):
         sum_out.write("# Args\n")
         argd = vars(args)
         for key in sorted(argd.keys()):
-            sum_out.write("%s\t%s\n" % (key, str(argd[key])))
+            sum_out.write(f"{key}\t{str(argd[key])}\n")
     joblib.dump(data, out_df)
